@@ -25,14 +25,18 @@ pub struct Opt {
     pub csv: bool,
 
     ///input is BGZF compressed (unnecessary if `-i` has suffix `.gz`)
-    #[structopt(short, long)]
+    #[structopt(long)]
     pub bgzip: bool,
 
-    /// Delimiting character to join sample names to fmt fields (default is "_")
-    #[structopt(short = "j", long = "sample-delim")]
-    pub sample_delim: Option<String>,
+    /// Prefix string for INFO fields to avoid name collisions (default is "info_")
+    #[structopt(long)]
+    pub info_prefix: Option<String>,
 
     /// Prefix string for INFO fields to avoid name collisions (default is "info_")
-    #[structopt(short = "p", long)]
-    pub info_prefix: Option<String>,
+    #[structopt(long)]
+    pub vep_prefix: Option<String>,
+
+    /// Delimiting character to join sample names to fmt fields (default is "_")
+    #[structopt(long)]
+    pub format_delim: Option<String>,
 }
