@@ -1,8 +1,9 @@
-use noodles_bgzf as bgzf;
-use noodles_vcf as vcf;
+use noodles::bgzf;
+use noodles::vcf;
+use vcf::header::info::Key;
 use vcf::record::chromosome::Chromosome;
 use vcf::record::filters::Filters;
-use vcf::record::info::field::{Key, Value};
+use vcf::record::info::field::Value;
 
 use structopt::StructOpt;
 
@@ -78,7 +79,7 @@ fn convert_records(
 
     match kind {
         TableKind::Cartesian => {
-            let sample_delim = match opt.sample_delim {
+            let sample_delim = match opt.format_delim {
                 Some(d) => d,
                 None => "_".to_string(),
             };
@@ -214,12 +215,11 @@ fn convert_records_cartesian(
     out_header.append(&mut info_header);
     let mut fmt_header: Vec<String> = samples
         .iter()
-        .map(|sample| {
+        .flat_map(|sample| {
             fmts.keys()
                 .map(|field| format!("{}{}{}", sample, sample_delim, field))
                 .collect::<Vec<String>>()
         })
-        .flatten()
         .collect();
 
     out_header.append(&mut fmt_header);
@@ -244,7 +244,7 @@ fn convert_records_cartesian(
             }
         }
 
-        writer.write_record(&fields).expect("fuck");
+        writer.write_record(&fields)?;
     }
     Ok(())
 }
@@ -257,7 +257,7 @@ fn push_info_fields(
 ) {
     for info_field in infos.keys() {
         match info_field {
-            // csq field and we want to split it
+            // CSQ field and we want to split it
             Key::Other(ref name, ..) if split_csq != 0 && name == "CSQ" => {
                 let field = info
                     .get(info_field)
@@ -266,7 +266,18 @@ fn push_info_fields(
                     .expect("No CSQ value!");
                 let mut subfields: Vec<String> = match field {
                     Value::String(s) => s.splitn(split_csq, '|').map(ToString::to_string).collect(),
-                    _ => panic!(),
+                    Value::StringArray(sa) => {
+                        let mut fields_string = String::new();
+                        for string in sa.iter().flatten() {
+                            fields_string.push_str(string);
+                            fields_string.push('|');
+                        }
+                        fields_string
+                            .splitn(split_csq, '|')
+                            .map(ToString::to_string)
+                            .collect()
+                    }
+                    _ => panic!("CSQ field not string(s)!"),
                 };
                 if subfields.len() < split_csq {
                     for _ in 0..(split_csq - subfields.len()) {
@@ -275,7 +286,7 @@ fn push_info_fields(
                 }
                 fields.append(&mut subfields);
             }
-            // single field
+            // non-CSQ field
             _ => fields.push(match info.get(info_field) {
                 None => "NA".to_owned(),
                 Some(field) => match field.value() {
